using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

using Syncfusion.Grouping;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Windows.Forms.Grid.Grouping;
using Syncfusion.Windows.Forms.Tools;

namespace DrillFilter
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
            gridGroupingControl1.TopLevelGroupOptions.ShowFilterBar = true;
            gridGroupingControl1.NestedTableGroupOptions.ShowFilterBar = true;
            
        }



        private int numberParentRows = 5;
        private int numberChildRows = 50;
        private DataTable GetParentTable()
        {
            DataTable dt = new DataTable("ParentTable");


            dt.Columns.Add(new DataColumn("parentID")); //lower case p
            dt.Columns.Add(new DataColumn("ParentName"));
            dt.Columns.Add(new DataColumn("ParentDec"));

            for (int i = 0; i < numberParentRows; ++i)
            {
                DataRow dr = dt.NewRow();
                dr[0] = i;//.ToString();
                dr[1] = string.Format("parentName{0}", i);
                dr[2] = string.Format("desc{0}", i);
                dt.Rows.Add(dr);
            }

            return dt;
        }

        private DataTable GetChildTable()
        {
            DataTable dt = new DataTable("ChildTable");

            dt.Columns.Add(new DataColumn("childID")); //lower case c
            dt.Columns.Add(new DataColumn("Name"));
            dt.Columns.Add(new DataColumn("ParentID")); //upper case P
            dt.Columns.Add(new DataColumn("MathScore", typeof(int))); //upper case P
            dt.Columns.Add(new DataColumn("ScienceScore", typeof(int))); //upper case P

            Random r = new Random();
            for (int i = 0; i < numberChildRows; ++i)
            {
                DataRow dr = dt.NewRow();
                dr[0] = i.ToString();
                dr[1] = string.Format("ChildName{0}", i);
                dr[2] = (i % numberParentRows).ToString();
                dr[3] = 50 + r.Next(50);
                dr[4] = 50 + r.Next(50);
                dt.Rows.Add(dr);
            }

            return dt;
        }

        private void btnRefresh_Click(object sender, EventArgs e)
        {
            DataTable parentTable = GetParentTable();
            DataTable childTable = GetChildTable();

            DataSet ds = new DataSet();
            ds.Tables.AddRange(new DataTable[] { parentTable, childTable });

            DataRelation parentToChild = new DataRelation("ParentToChild", parentTable.Columns["parentID"], childTable.Columns["ParentID"]);

            ds.Relations.AddRange(new DataRelation[] { parentToChild });

            this.gridGroupingControl1.DataSource = parentTable;

            GridEngine myEngine = new GridEngine();

            myEngine.TopLevelGroupOptions.ShowCaption = false;
            myEngine.TopLevelGroupOptions.ShowFilterBar = true;
            myEngine.TopLevelGroupOptions.ShowColumnHeaders = true;

            // Ugnijedena tablica
            myEngine.NestedTableGroupOptions.ShowFilterBar = true;
            myEngine.NestedTableGroupOptions.ShowSummaries = false;
            myEngine.NestedTableGroupOptions.ShowEmptyGroups = true;
            myEngine.NestedTableGroupOptions.ShowColumnHeaders = true;

            myEngine.TopLevelGroupOptions.ShowAddNewRecordBeforeDetails = false;
            myEngine.TopLevelGroupOptions.ShowAddNewRecordAfterDetails = false;

            myEngine.NestedTableGroupOptions.ShowAddNewRecordBeforeDetails = false;
            myEngine.NestedTableGroupOptions.ShowAddNewRecordAfterDetails = false;

            myEngine.ChildGroupOptions.ShowAddNewRecordBeforeDetails = false;
            myEngine.ChildGroupOptions.ShowAddNewRecordAfterDetails = false;

            gridGroupingControl1.Engine = myEngine;



        }

        private void button1_Click(object sender, EventArgs e)
        {
            // I had to bind this to a button click because if I put this code right after the Datasource
            // is assigned it doesn't work. It seems that column descriptors arent still initialized properly.
            foreach (GridColumnDescriptor gcd in gridGroupingControl1.GetTableDescriptor("ParentTable").Columns)
            {
                //gcd.Appearance.FilterBarCell.CellType = "FilterBarCell";
                gcd.AllowFilter = true;
            }

            foreach (GridColumnDescriptor gcd in gridGroupingControl1.GetTableDescriptor("ChildTable").Columns)
            {
                gcd.AllowFilter = true;
            }

            // If you mess around with the filters a bit the control will throw an exception for no apparent reason
            //
            // And there are more things I'd like to solve:
            // for instance why it doesnt the grid refresh properly after I remove the filter in nested table?
            // It just stretches the record beneath it and doesn't show all the nested tables records
            // until I collapse it and then expand it again
        }
    }
}